Index: tests/phpunit/includes/utils.php
===================================================================
--- tests/phpunit/includes/utils.php	(revision 37402)
+++ tests/phpunit/includes/utils.php	(working copy)
@@ -108,13 +108,14 @@
 		return $this->events;
 	}

 	// return a count of the number of times the action was called since the last reset
 	function get_call_count($tag='') {
 		if ($tag) {
 			$count = 0;
 			foreach ($this->events as $e)
-				if ($e['action'] == $tag)
+				if ( ( isset( $e['action'] ) && $e['action'] == $tag ) || ( isset( $e['filter'] ) && $e['filter'] == $tag ) ) {
 					++$count;
+				}
 			return $count;
 		}
 		return count($this->events);
@@ -108,13 +108,14 @@
 	}

-	// return a count of the number of times the action was called since the last reset
+	// Return a count of the number of times an action or filter was called since the last reset.
 	function get_call_count($tag='') {
 		if ($tag) {
